# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: time.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='time.proto',
  package='time',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.timeP\001Z\024biostar/service/time'),
  serialized_pb=_b('\n\ntime.proto\x12\x04time\x1a\terr.proto\"\x1e\n\nGetRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1e\n\x0bGetResponse\x12\x0f\n\x07GMTTime\x18\x01 \x01(\x04\"/\n\nSetRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0f\n\x07GMTTime\x18\x02 \x01(\x04\"\r\n\x0bSetResponse\"5\n\x0fSetMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x0f\n\x07GMTTime\x18\x02 \x01(\x04\"<\n\x10SetMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"6\n\nTimeConfig\x12\x10\n\x08timeZone\x18\x01 \x01(\x05\x12\x16\n\x0esyncWithServer\x18\x02 \x01(\x08\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x11GetConfigResponse\x12 \n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x10.time.TimeConfig\"F\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.time.TimeConfig\"\x13\n\x11SetConfigResponse\"L\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.time.TimeConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xa2\x01\n\x08WeekTime\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x1a\n\x05month\x18\x02 \x01(\x0e\x32\x0b.time.Month\x12\x1e\n\x07ordinal\x18\x03 \x01(\x0e\x32\r.time.Ordinal\x12\x1e\n\x07weekday\x18\x04 \x01(\x0e\x32\r.time.Weekday\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\x12\x0e\n\x06second\x18\x07 \x01(\r\"e\n\x0b\x44STSchedule\x12!\n\tstartTime\x18\x01 \x01(\x0b\x32\x0e.time.WeekTime\x12\x1f\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32\x0e.time.WeekTime\x12\x12\n\ntimeOffset\x18\x03 \x01(\x05\"1\n\tDSTConfig\x12$\n\tschedules\x18\x01 \x03(\x0b\x32\x11.time.DSTSchedule\"\'\n\x13GetDSTConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"7\n\x14GetDSTConfigResponse\x12\x1f\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0f.time.DSTConfig\"H\n\x13SetDSTConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1f\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0f.time.DSTConfig\"\x16\n\x14SetDSTConfigResponse\"N\n\x18SetDSTConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x1f\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0f.time.DSTConfig\"E\n\x19SetDSTConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\xe1\x01\n\x05Month\x12\x11\n\rMONTH_JANUARY\x10\x00\x12\x12\n\x0eMONTH_FEBRUARY\x10\x01\x12\x0f\n\x0bMONTH_MARCH\x10\x02\x12\x0f\n\x0bMONTH_APRIL\x10\x03\x12\r\n\tMONTH_MAY\x10\x04\x12\x0e\n\nMONTH_JUNE\x10\x05\x12\x0e\n\nMONTH_JULY\x10\x06\x12\x10\n\x0cMONTH_AUGUST\x10\x07\x12\x13\n\x0fMONTH_SEPTEMBER\x10\x08\x12\x11\n\rMONTH_OCTOBER\x10\t\x12\x12\n\x0eMONTH_NOVEMBER\x10\n\x12\x12\n\x0eMONTH_DECEMBER\x10\x0b*\x9d\x01\n\x07Weekday\x12\x12\n\x0eWEEKDAY_SUNDAY\x10\x00\x12\x12\n\x0eWEEKDAY_MONDAY\x10\x01\x12\x13\n\x0fWEEKDAY_TUESDAY\x10\x02\x12\x15\n\x11WEEKDAY_WEDNESDAY\x10\x03\x12\x14\n\x10WEEKDAY_THURSDAY\x10\x04\x12\x12\n\x0eWEEKDAY_FRIDAY\x10\x05\x12\x14\n\x10WEEKDAY_SATURDAY\x10\x06*\xe7\x01\n\x07Ordinal\x12\x11\n\rORDINAL_FIRST\x10\x00\x12\x12\n\x0eORDINAL_SECOND\x10\x01\x12\x11\n\rORDINAL_THIRD\x10\x02\x12\x12\n\x0eORDINAL_FOURTH\x10\x03\x12\x11\n\rORDINAL_FIFTH\x10\x04\x12\x11\n\rORDINAL_SIXTH\x10\x05\x12\x13\n\x0fORDINAL_SEVENTH\x10\x06\x12\x12\n\x0eORDINAL_EIGHTH\x10\x07\x12\x11\n\rORDINAL_NINTH\x10\x08\x12\x11\n\rORDINAL_TENTH\x10\t\x12\x19\n\x0cORDINAL_LAST\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x32\xc6\x04\n\x04Time\x12*\n\x03Get\x12\x10.time.GetRequest\x1a\x11.time.GetResponse\x12*\n\x03Set\x12\x10.time.SetRequest\x1a\x11.time.SetResponse\x12\x39\n\x08SetMulti\x12\x15.time.SetMultiRequest\x1a\x16.time.SetMultiResponse\x12<\n\tGetConfig\x12\x16.time.GetConfigRequest\x1a\x17.time.GetConfigResponse\x12<\n\tSetConfig\x12\x16.time.SetConfigRequest\x1a\x17.time.SetConfigResponse\x12K\n\x0eSetConfigMulti\x12\x1b.time.SetConfigMultiRequest\x1a\x1c.time.SetConfigMultiResponse\x12\x45\n\x0cGetDSTConfig\x12\x19.time.GetDSTConfigRequest\x1a\x1a.time.GetDSTConfigResponse\x12\x45\n\x0cSetDSTConfig\x12\x19.time.SetDSTConfigRequest\x1a\x1a.time.SetDSTConfigResponse\x12T\n\x11SetDSTConfigMulti\x12\x1e.time.SetDSTConfigMultiRequest\x1a\x1f.time.SetDSTConfigMultiResponseB1\n\x17\x63om.supremainc.sdk.timeP\x01Z\x14\x62iostar/service/timeb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_MONTH = _descriptor.EnumDescriptor(
  name='Month',
  full_name='time.Month',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MONTH_JANUARY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_FEBRUARY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_MARCH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_APRIL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_MAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_JUNE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_JULY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_AUGUST', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_SEPTEMBER', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_OCTOBER', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_NOVEMBER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_DECEMBER', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1331,
  serialized_end=1556,
)
_sym_db.RegisterEnumDescriptor(_MONTH)

Month = enum_type_wrapper.EnumTypeWrapper(_MONTH)
_WEEKDAY = _descriptor.EnumDescriptor(
  name='Weekday',
  full_name='time.Weekday',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_SUNDAY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_MONDAY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_TUESDAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_WEDNESDAY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_THURSDAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_FRIDAY', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_SATURDAY', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1559,
  serialized_end=1716,
)
_sym_db.RegisterEnumDescriptor(_WEEKDAY)

Weekday = enum_type_wrapper.EnumTypeWrapper(_WEEKDAY)
_ORDINAL = _descriptor.EnumDescriptor(
  name='Ordinal',
  full_name='time.Ordinal',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FIRST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SECOND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_THIRD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FOURTH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FIFTH', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SIXTH', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SEVENTH', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_EIGHTH', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_NINTH', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_TENTH', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_LAST', index=10, number=-1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1719,
  serialized_end=1950,
)
_sym_db.RegisterEnumDescriptor(_ORDINAL)

Ordinal = enum_type_wrapper.EnumTypeWrapper(_ORDINAL)
MONTH_JANUARY = 0
MONTH_FEBRUARY = 1
MONTH_MARCH = 2
MONTH_APRIL = 3
MONTH_MAY = 4
MONTH_JUNE = 5
MONTH_JULY = 6
MONTH_AUGUST = 7
MONTH_SEPTEMBER = 8
MONTH_OCTOBER = 9
MONTH_NOVEMBER = 10
MONTH_DECEMBER = 11
WEEKDAY_SUNDAY = 0
WEEKDAY_MONDAY = 1
WEEKDAY_TUESDAY = 2
WEEKDAY_WEDNESDAY = 3
WEEKDAY_THURSDAY = 4
WEEKDAY_FRIDAY = 5
WEEKDAY_SATURDAY = 6
ORDINAL_FIRST = 0
ORDINAL_SECOND = 1
ORDINAL_THIRD = 2
ORDINAL_FOURTH = 3
ORDINAL_FIFTH = 4
ORDINAL_SIXTH = 5
ORDINAL_SEVENTH = 6
ORDINAL_EIGHTH = 7
ORDINAL_NINTH = 8
ORDINAL_TENTH = 9
ORDINAL_LAST = -1



_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='time.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=61,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='time.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.GetResponse.GMTTime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=93,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='time.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.SetRequest.GMTTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=142,
)


_SETRESPONSE = _descriptor.Descriptor(
  name='SetResponse',
  full_name='time.SetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=157,
)


_SETMULTIREQUEST = _descriptor.Descriptor(
  name='SetMultiRequest',
  full_name='time.SetMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.SetMultiRequest.GMTTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=212,
)


_SETMULTIRESPONSE = _descriptor.Descriptor(
  name='SetMultiResponse',
  full_name='time.SetMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=274,
)


_TIMECONFIG = _descriptor.Descriptor(
  name='TimeConfig',
  full_name='time.TimeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeZone', full_name='time.TimeConfig.timeZone', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='syncWithServer', full_name='time.TimeConfig.syncWithServer', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=330,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='time.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=368,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='time.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='time.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=423,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='time.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=495,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='time.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=516,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='time.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=594,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='time.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=662,
)


_WEEKTIME = _descriptor.Descriptor(
  name='WeekTime',
  full_name='time.WeekTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='time.WeekTime.year', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month', full_name='time.WeekTime.month', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='time.WeekTime.ordinal', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekday', full_name='time.WeekTime.weekday', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hour', full_name='time.WeekTime.hour', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minute', full_name='time.WeekTime.minute', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='second', full_name='time.WeekTime.second', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=827,
)


_DSTSCHEDULE = _descriptor.Descriptor(
  name='DSTSchedule',
  full_name='time.DSTSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='time.DSTSchedule.startTime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='time.DSTSchedule.endTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeOffset', full_name='time.DSTSchedule.timeOffset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=930,
)


_DSTCONFIG = _descriptor.Descriptor(
  name='DSTConfig',
  full_name='time.DSTConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='time.DSTConfig.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=981,
)


_GETDSTCONFIGREQUEST = _descriptor.Descriptor(
  name='GetDSTConfigRequest',
  full_name='time.GetDSTConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetDSTConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1022,
)


_GETDSTCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetDSTConfigResponse',
  full_name='time.GetDSTConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='time.GetDSTConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1079,
)


_SETDSTCONFIGREQUEST = _descriptor.Descriptor(
  name='SetDSTConfigRequest',
  full_name='time.SetDSTConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetDSTConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetDSTConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1153,
)


_SETDSTCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetDSTConfigResponse',
  full_name='time.SetDSTConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1177,
)


_SETDSTCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetDSTConfigMultiRequest',
  full_name='time.SetDSTConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetDSTConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetDSTConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1257,
)


_SETDSTCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetDSTConfigMultiResponse',
  full_name='time.SetDSTConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetDSTConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1328,
)

_SETMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_WEEKTIME.fields_by_name['month'].enum_type = _MONTH
_WEEKTIME.fields_by_name['ordinal'].enum_type = _ORDINAL
_WEEKTIME.fields_by_name['weekday'].enum_type = _WEEKDAY
_DSTSCHEDULE.fields_by_name['startTime'].message_type = _WEEKTIME
_DSTSCHEDULE.fields_by_name['endTime'].message_type = _WEEKTIME
_DSTCONFIG.fields_by_name['schedules'].message_type = _DSTSCHEDULE
_GETDSTCONFIGRESPONSE.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGREQUEST.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['SetResponse'] = _SETRESPONSE
DESCRIPTOR.message_types_by_name['SetMultiRequest'] = _SETMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetMultiResponse'] = _SETMULTIRESPONSE
DESCRIPTOR.message_types_by_name['TimeConfig'] = _TIMECONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['WeekTime'] = _WEEKTIME
DESCRIPTOR.message_types_by_name['DSTSchedule'] = _DSTSCHEDULE
DESCRIPTOR.message_types_by_name['DSTConfig'] = _DSTCONFIG
DESCRIPTOR.message_types_by_name['GetDSTConfigRequest'] = _GETDSTCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetDSTConfigResponse'] = _GETDSTCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetDSTConfigRequest'] = _SETDSTCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetDSTConfigResponse'] = _SETDSTCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetDSTConfigMultiRequest'] = _SETDSTCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetDSTConfigMultiResponse'] = _SETDSTCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['Month'] = _MONTH
DESCRIPTOR.enum_types_by_name['Weekday'] = _WEEKDAY
DESCRIPTOR.enum_types_by_name['Ordinal'] = _ORDINAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

SetResponse = _reflection.GeneratedProtocolMessageType('SetResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetResponse)
  ))
_sym_db.RegisterMessage(SetResponse)

SetMultiRequest = _reflection.GeneratedProtocolMessageType('SetMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetMultiRequest)
  ))
_sym_db.RegisterMessage(SetMultiRequest)

SetMultiResponse = _reflection.GeneratedProtocolMessageType('SetMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetMultiResponse)
  ))
_sym_db.RegisterMessage(SetMultiResponse)

TimeConfig = _reflection.GeneratedProtocolMessageType('TimeConfig', (_message.Message,), dict(
  DESCRIPTOR = _TIMECONFIG,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.TimeConfig)
  ))
_sym_db.RegisterMessage(TimeConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

WeekTime = _reflection.GeneratedProtocolMessageType('WeekTime', (_message.Message,), dict(
  DESCRIPTOR = _WEEKTIME,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.WeekTime)
  ))
_sym_db.RegisterMessage(WeekTime)

DSTSchedule = _reflection.GeneratedProtocolMessageType('DSTSchedule', (_message.Message,), dict(
  DESCRIPTOR = _DSTSCHEDULE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.DSTSchedule)
  ))
_sym_db.RegisterMessage(DSTSchedule)

DSTConfig = _reflection.GeneratedProtocolMessageType('DSTConfig', (_message.Message,), dict(
  DESCRIPTOR = _DSTCONFIG,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.DSTConfig)
  ))
_sym_db.RegisterMessage(DSTConfig)

GetDSTConfigRequest = _reflection.GeneratedProtocolMessageType('GetDSTConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDSTCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetDSTConfigRequest)
  ))
_sym_db.RegisterMessage(GetDSTConfigRequest)

GetDSTConfigResponse = _reflection.GeneratedProtocolMessageType('GetDSTConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDSTCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetDSTConfigResponse)
  ))
_sym_db.RegisterMessage(GetDSTConfigResponse)

SetDSTConfigRequest = _reflection.GeneratedProtocolMessageType('SetDSTConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigRequest)
  ))
_sym_db.RegisterMessage(SetDSTConfigRequest)

SetDSTConfigResponse = _reflection.GeneratedProtocolMessageType('SetDSTConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigResponse)
  ))
_sym_db.RegisterMessage(SetDSTConfigResponse)

SetDSTConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetDSTConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetDSTConfigMultiRequest)

SetDSTConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetDSTConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetDSTConfigMultiResponse)


DESCRIPTOR._options = None

_TIME = _descriptor.ServiceDescriptor(
  name='Time',
  full_name='time.Time',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1953,
  serialized_end=2535,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='time.Time.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='time.Time.Set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=_SETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetMulti',
    full_name='time.Time.SetMulti',
    index=2,
    containing_service=None,
    input_type=_SETMULTIREQUEST,
    output_type=_SETMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='time.Time.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='time.Time.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='time.Time.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDSTConfig',
    full_name='time.Time.GetDSTConfig',
    index=6,
    containing_service=None,
    input_type=_GETDSTCONFIGREQUEST,
    output_type=_GETDSTCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSTConfig',
    full_name='time.Time.SetDSTConfig',
    index=7,
    containing_service=None,
    input_type=_SETDSTCONFIGREQUEST,
    output_type=_SETDSTCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSTConfigMulti',
    full_name='time.Time.SetDSTConfigMulti',
    index=8,
    containing_service=None,
    input_type=_SETDSTCONFIGMULTIREQUEST,
    output_type=_SETDSTCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TIME)

DESCRIPTOR.services_by_name['Time'] = _TIME

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: display.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='display.proto',
  package='display',
  syntax='proto3',
  serialized_options=_b('\n\032com.supremainc.sdk.displayP\001Z\027biostar/service/display'),
  serialized_pb=_b('\n\rdisplay.proto\x12\x07\x64isplay\x1a\terr.proto\"\x8b\x03\n\rDisplayConfig\x12\'\n\x08language\x18\x01 \x01(\x0e\x32\x15.display.LanguageType\x12+\n\nbackground\x18\x02 \x01(\x0e\x32\x17.display.BackgroundType\x12\'\n\x05theme\x18\x03 \x01(\x0e\x32\x18.display.BackgroundTheme\x12\x0e\n\x06volume\x18\x04 \x01(\r\x12\x10\n\x08useVoice\x18\x05 \x01(\x08\x12\'\n\ndateFormat\x18\x06 \x01(\x0e\x32\x13.display.DateFormat\x12\'\n\ntimeFormat\x18\x07 \x01(\x0e\x32\x13.display.TimeFormat\x12\x14\n\x0cshowDateTime\x18\x08 \x01(\x08\x12\x13\n\x0bmenuTimeout\x18\t \x01(\r\x12\x12\n\nmsgTimeout\x18\n \x01(\r\x12\x18\n\x10\x62\x61\x63klightTimeout\x18\x0b \x01(\r\x12\x15\n\ruseUserPhrase\x18\x0c \x01(\x08\x12\x17\n\x0fqueryUserPhrase\x18\r \x01(\x08\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\";\n\x11GetConfigResponse\x12&\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x16.display.DisplayConfig\"L\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x16.display.DisplayConfig\"\x13\n\x11SetConfigResponse\"R\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12&\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x16.display.DisplayConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\";\n\x19UpdateLanguagePackRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x1c\n\x1aUpdateLanguagePackResponse\"A\n\x1eUpdateLanguagePackMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"K\n\x1fUpdateLanguagePackMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"7\n\x13UpdateNoticeRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0e\n\x06notice\x18\x02 \x01(\t\"\x16\n\x14UpdateNoticeResponse\"=\n\x18UpdateNoticeMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x0e\n\x06notice\x18\x02 \x01(\t\"E\n\x19UpdateNoticeMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"B\n\x1cUpdateBackgroundImageRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08PNGImage\x18\x02 \x01(\x0c\"\x1f\n\x1dUpdateBackgroundImageResponse\"H\n!UpdateBackgroundImageMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08PNGImage\x18\x02 \x01(\x0c\"N\n\"UpdateBackgroundImageMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"?\n\x18UpdateSlideImagesRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x11\n\tPNGImages\x18\x02 \x03(\x0c\"\x1b\n\x19UpdateSlideImagesResponse\"E\n\x1dUpdateSlideImagesMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x11\n\tPNGImages\x18\x02 \x03(\x0c\"J\n\x1eUpdateSlideImagesMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\\\n\x12UpdateSoundRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x05index\x18\x02 \x01(\x0e\x32\x13.display.SoundIndex\x12\x10\n\x08waveData\x18\x03 \x01(\x0c\"\x15\n\x13UpdateSoundResponse\"b\n\x17UpdateSoundMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x05index\x18\x02 \x01(\x0e\x32\x13.display.SoundIndex\x12\x10\n\x08waveData\x18\x03 \x01(\x0c\"D\n\x18UpdateSoundMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*Z\n\x0cLanguageType\x12\x17\n\x13\x42S2_LANGUAGE_KOREAN\x10\x00\x12\x18\n\x14\x42S2_LANGUAGE_ENGLISH\x10\x01\x12\x17\n\x13\x42S2_LANGUAGE_CUSTOM\x10\x02*V\n\x0e\x42\x61\x63kgroundType\x12\x0f\n\x0b\x42S2_BG_LOGO\x10\x00\x12\x11\n\rBS2_BG_NOTICE\x10\x01\x12\x10\n\x0c\x42S2_BG_SLIDE\x10\x02\x12\x0e\n\nBS2_BG_PDF\x10\x03*e\n\x0f\x42\x61\x63kgroundTheme\x12\x13\n\x0f\x42S2_BG_THEME_01\x10\x00\x12\x13\n\x0f\x42S2_BG_THEME_02\x10\x01\x12\x13\n\x0f\x42S2_BG_THEME_03\x10\x02\x12\x13\n\x0f\x42S2_BG_THEME_04\x10\x03*f\n\nDateFormat\x12\x1c\n\x18\x42S2_DATE_FORMAT_YYYYMMDD\x10\x00\x12\x1c\n\x18\x42S2_DATE_FORMAT_MMDDYYYY\x10\x01\x12\x1c\n\x18\x42S2_DATE_FORMAT_DDMMYYYY\x10\x02*F\n\nTimeFormat\x12\x1b\n\x17\x42S2_TIME_FORMAT_12_HOUR\x10\x00\x12\x1b\n\x17\x42S2_TIME_FORMAT_24_HOUR\x10\x01*\x90\x01\n\nSoundIndex\x12\x17\n\x13SOUND_INDEX_WELCOME\x10\x00\x12\x1c\n\x18SOUND_INDEX_AUTH_SUCCESS\x10\x01\x12\x19\n\x15SOUND_INDEX_AUTH_FAIL\x10\x02\x12\x17\n\x13SOUND_INDEX_ALARM_1\x10\x03\x12\x17\n\x13SOUND_INDEX_ALARM_2\x10\x04\x32\xa3\t\n\x07\x44isplay\x12]\n\x12UpdateLanguagePack\x12\".display.UpdateLanguagePackRequest\x1a#.display.UpdateLanguagePackResponse\x12l\n\x17UpdateLanguagePackMulti\x12\'.display.UpdateLanguagePackMultiRequest\x1a(.display.UpdateLanguagePackMultiResponse\x12K\n\x0cUpdateNotice\x12\x1c.display.UpdateNoticeRequest\x1a\x1d.display.UpdateNoticeResponse\x12Z\n\x11UpdateNoticeMulti\x12!.display.UpdateNoticeMultiRequest\x1a\".display.UpdateNoticeMultiResponse\x12\x66\n\x15UpdateBackgroundImage\x12%.display.UpdateBackgroundImageRequest\x1a&.display.UpdateBackgroundImageResponse\x12u\n\x1aUpdateBackgroundImageMulti\x12*.display.UpdateBackgroundImageMultiRequest\x1a+.display.UpdateBackgroundImageMultiResponse\x12Z\n\x11UpdateSlideImages\x12!.display.UpdateSlideImagesRequest\x1a\".display.UpdateSlideImagesResponse\x12i\n\x16UpdateSlideImagesMulti\x12&.display.UpdateSlideImagesMultiRequest\x1a\'.display.UpdateSlideImagesMultiResponse\x12H\n\x0bUpdateSound\x12\x1b.display.UpdateSoundRequest\x1a\x1c.display.UpdateSoundResponse\x12W\n\x10UpdateSoundMulti\x12 .display.UpdateSoundMultiRequest\x1a!.display.UpdateSoundMultiResponse\x12\x42\n\tGetConfig\x12\x19.display.GetConfigRequest\x1a\x1a.display.GetConfigResponse\x12\x42\n\tSetConfig\x12\x19.display.SetConfigRequest\x1a\x1a.display.SetConfigResponse\x12Q\n\x0eSetConfigMulti\x12\x1e.display.SetConfigMultiRequest\x1a\x1f.display.SetConfigMultiResponseB7\n\x1a\x63om.supremainc.sdk.displayP\x01Z\x17\x62iostar/service/displayb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_LANGUAGETYPE = _descriptor.EnumDescriptor(
  name='LanguageType',
  full_name='display.LanguageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_LANGUAGE_KOREAN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_LANGUAGE_ENGLISH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_LANGUAGE_CUSTOM', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2018,
  serialized_end=2108,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGETYPE)

LanguageType = enum_type_wrapper.EnumTypeWrapper(_LANGUAGETYPE)
_BACKGROUNDTYPE = _descriptor.EnumDescriptor(
  name='BackgroundType',
  full_name='display.BackgroundType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_LOGO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_NOTICE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_SLIDE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_PDF', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2110,
  serialized_end=2196,
)
_sym_db.RegisterEnumDescriptor(_BACKGROUNDTYPE)

BackgroundType = enum_type_wrapper.EnumTypeWrapper(_BACKGROUNDTYPE)
_BACKGROUNDTHEME = _descriptor.EnumDescriptor(
  name='BackgroundTheme',
  full_name='display.BackgroundTheme',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_THEME_01', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_THEME_02', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_THEME_03', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_BG_THEME_04', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2198,
  serialized_end=2299,
)
_sym_db.RegisterEnumDescriptor(_BACKGROUNDTHEME)

BackgroundTheme = enum_type_wrapper.EnumTypeWrapper(_BACKGROUNDTHEME)
_DATEFORMAT = _descriptor.EnumDescriptor(
  name='DateFormat',
  full_name='display.DateFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_DATE_FORMAT_YYYYMMDD', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_DATE_FORMAT_MMDDYYYY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_DATE_FORMAT_DDMMYYYY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2301,
  serialized_end=2403,
)
_sym_db.RegisterEnumDescriptor(_DATEFORMAT)

DateFormat = enum_type_wrapper.EnumTypeWrapper(_DATEFORMAT)
_TIMEFORMAT = _descriptor.EnumDescriptor(
  name='TimeFormat',
  full_name='display.TimeFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BS2_TIME_FORMAT_12_HOUR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_TIME_FORMAT_24_HOUR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2405,
  serialized_end=2475,
)
_sym_db.RegisterEnumDescriptor(_TIMEFORMAT)

TimeFormat = enum_type_wrapper.EnumTypeWrapper(_TIMEFORMAT)
_SOUNDINDEX = _descriptor.EnumDescriptor(
  name='SoundIndex',
  full_name='display.SoundIndex',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SOUND_INDEX_WELCOME', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND_INDEX_AUTH_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND_INDEX_AUTH_FAIL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND_INDEX_ALARM_1', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOUND_INDEX_ALARM_2', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2478,
  serialized_end=2622,
)
_sym_db.RegisterEnumDescriptor(_SOUNDINDEX)

SoundIndex = enum_type_wrapper.EnumTypeWrapper(_SOUNDINDEX)
BS2_LANGUAGE_KOREAN = 0
BS2_LANGUAGE_ENGLISH = 1
BS2_LANGUAGE_CUSTOM = 2
BS2_BG_LOGO = 0
BS2_BG_NOTICE = 1
BS2_BG_SLIDE = 2
BS2_BG_PDF = 3
BS2_BG_THEME_01 = 0
BS2_BG_THEME_02 = 1
BS2_BG_THEME_03 = 2
BS2_BG_THEME_04 = 3
BS2_DATE_FORMAT_YYYYMMDD = 0
BS2_DATE_FORMAT_MMDDYYYY = 1
BS2_DATE_FORMAT_DDMMYYYY = 2
BS2_TIME_FORMAT_12_HOUR = 0
BS2_TIME_FORMAT_24_HOUR = 1
SOUND_INDEX_WELCOME = 0
SOUND_INDEX_AUTH_SUCCESS = 1
SOUND_INDEX_AUTH_FAIL = 2
SOUND_INDEX_ALARM_1 = 3
SOUND_INDEX_ALARM_2 = 4



_DISPLAYCONFIG = _descriptor.Descriptor(
  name='DisplayConfig',
  full_name='display.DisplayConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='display.DisplayConfig.language', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background', full_name='display.DisplayConfig.background', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='display.DisplayConfig.theme', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='volume', full_name='display.DisplayConfig.volume', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useVoice', full_name='display.DisplayConfig.useVoice', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dateFormat', full_name='display.DisplayConfig.dateFormat', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeFormat', full_name='display.DisplayConfig.timeFormat', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showDateTime', full_name='display.DisplayConfig.showDateTime', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='menuTimeout', full_name='display.DisplayConfig.menuTimeout', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msgTimeout', full_name='display.DisplayConfig.msgTimeout', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backlightTimeout', full_name='display.DisplayConfig.backlightTimeout', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useUserPhrase', full_name='display.DisplayConfig.useUserPhrase', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queryUserPhrase', full_name='display.DisplayConfig.queryUserPhrase', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=433,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='display.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=471,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='display.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='display.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=532,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='display.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='display.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=610,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='display.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=631,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='display.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='display.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=715,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='display.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=783,
)


_UPDATELANGUAGEPACKREQUEST = _descriptor.Descriptor(
  name='UpdateLanguagePackRequest',
  full_name='display.UpdateLanguagePackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.UpdateLanguagePackRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='display.UpdateLanguagePackRequest.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=844,
)


_UPDATELANGUAGEPACKRESPONSE = _descriptor.Descriptor(
  name='UpdateLanguagePackResponse',
  full_name='display.UpdateLanguagePackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=874,
)


_UPDATELANGUAGEPACKMULTIREQUEST = _descriptor.Descriptor(
  name='UpdateLanguagePackMultiRequest',
  full_name='display.UpdateLanguagePackMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.UpdateLanguagePackMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='display.UpdateLanguagePackMultiRequest.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=941,
)


_UPDATELANGUAGEPACKMULTIRESPONSE = _descriptor.Descriptor(
  name='UpdateLanguagePackMultiResponse',
  full_name='display.UpdateLanguagePackMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.UpdateLanguagePackMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1018,
)


_UPDATENOTICEREQUEST = _descriptor.Descriptor(
  name='UpdateNoticeRequest',
  full_name='display.UpdateNoticeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.UpdateNoticeRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notice', full_name='display.UpdateNoticeRequest.notice', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1075,
)


_UPDATENOTICERESPONSE = _descriptor.Descriptor(
  name='UpdateNoticeResponse',
  full_name='display.UpdateNoticeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1099,
)


_UPDATENOTICEMULTIREQUEST = _descriptor.Descriptor(
  name='UpdateNoticeMultiRequest',
  full_name='display.UpdateNoticeMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.UpdateNoticeMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notice', full_name='display.UpdateNoticeMultiRequest.notice', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1162,
)


_UPDATENOTICEMULTIRESPONSE = _descriptor.Descriptor(
  name='UpdateNoticeMultiResponse',
  full_name='display.UpdateNoticeMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.UpdateNoticeMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1233,
)


_UPDATEBACKGROUNDIMAGEREQUEST = _descriptor.Descriptor(
  name='UpdateBackgroundImageRequest',
  full_name='display.UpdateBackgroundImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.UpdateBackgroundImageRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PNGImage', full_name='display.UpdateBackgroundImageRequest.PNGImage', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1301,
)


_UPDATEBACKGROUNDIMAGERESPONSE = _descriptor.Descriptor(
  name='UpdateBackgroundImageResponse',
  full_name='display.UpdateBackgroundImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1334,
)


_UPDATEBACKGROUNDIMAGEMULTIREQUEST = _descriptor.Descriptor(
  name='UpdateBackgroundImageMultiRequest',
  full_name='display.UpdateBackgroundImageMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.UpdateBackgroundImageMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PNGImage', full_name='display.UpdateBackgroundImageMultiRequest.PNGImage', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1408,
)


_UPDATEBACKGROUNDIMAGEMULTIRESPONSE = _descriptor.Descriptor(
  name='UpdateBackgroundImageMultiResponse',
  full_name='display.UpdateBackgroundImageMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.UpdateBackgroundImageMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1410,
  serialized_end=1488,
)


_UPDATESLIDEIMAGESREQUEST = _descriptor.Descriptor(
  name='UpdateSlideImagesRequest',
  full_name='display.UpdateSlideImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.UpdateSlideImagesRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PNGImages', full_name='display.UpdateSlideImagesRequest.PNGImages', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1490,
  serialized_end=1553,
)


_UPDATESLIDEIMAGESRESPONSE = _descriptor.Descriptor(
  name='UpdateSlideImagesResponse',
  full_name='display.UpdateSlideImagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1555,
  serialized_end=1582,
)


_UPDATESLIDEIMAGESMULTIREQUEST = _descriptor.Descriptor(
  name='UpdateSlideImagesMultiRequest',
  full_name='display.UpdateSlideImagesMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.UpdateSlideImagesMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PNGImages', full_name='display.UpdateSlideImagesMultiRequest.PNGImages', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1584,
  serialized_end=1653,
)


_UPDATESLIDEIMAGESMULTIRESPONSE = _descriptor.Descriptor(
  name='UpdateSlideImagesMultiResponse',
  full_name='display.UpdateSlideImagesMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.UpdateSlideImagesMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1729,
)


_UPDATESOUNDREQUEST = _descriptor.Descriptor(
  name='UpdateSoundRequest',
  full_name='display.UpdateSoundRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='display.UpdateSoundRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='display.UpdateSoundRequest.index', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveData', full_name='display.UpdateSoundRequest.waveData', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1731,
  serialized_end=1823,
)


_UPDATESOUNDRESPONSE = _descriptor.Descriptor(
  name='UpdateSoundResponse',
  full_name='display.UpdateSoundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1825,
  serialized_end=1846,
)


_UPDATESOUNDMULTIREQUEST = _descriptor.Descriptor(
  name='UpdateSoundMultiRequest',
  full_name='display.UpdateSoundMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='display.UpdateSoundMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='display.UpdateSoundMultiRequest.index', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveData', full_name='display.UpdateSoundMultiRequest.waveData', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1946,
)


_UPDATESOUNDMULTIRESPONSE = _descriptor.Descriptor(
  name='UpdateSoundMultiResponse',
  full_name='display.UpdateSoundMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='display.UpdateSoundMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1948,
  serialized_end=2016,
)

_DISPLAYCONFIG.fields_by_name['language'].enum_type = _LANGUAGETYPE
_DISPLAYCONFIG.fields_by_name['background'].enum_type = _BACKGROUNDTYPE
_DISPLAYCONFIG.fields_by_name['theme'].enum_type = _BACKGROUNDTHEME
_DISPLAYCONFIG.fields_by_name['dateFormat'].enum_type = _DATEFORMAT
_DISPLAYCONFIG.fields_by_name['timeFormat'].enum_type = _TIMEFORMAT
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _DISPLAYCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _DISPLAYCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _DISPLAYCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_UPDATELANGUAGEPACKMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_UPDATENOTICEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_UPDATEBACKGROUNDIMAGEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_UPDATESLIDEIMAGESMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_UPDATESOUNDREQUEST.fields_by_name['index'].enum_type = _SOUNDINDEX
_UPDATESOUNDMULTIREQUEST.fields_by_name['index'].enum_type = _SOUNDINDEX
_UPDATESOUNDMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['DisplayConfig'] = _DISPLAYCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['UpdateLanguagePackRequest'] = _UPDATELANGUAGEPACKREQUEST
DESCRIPTOR.message_types_by_name['UpdateLanguagePackResponse'] = _UPDATELANGUAGEPACKRESPONSE
DESCRIPTOR.message_types_by_name['UpdateLanguagePackMultiRequest'] = _UPDATELANGUAGEPACKMULTIREQUEST
DESCRIPTOR.message_types_by_name['UpdateLanguagePackMultiResponse'] = _UPDATELANGUAGEPACKMULTIRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNoticeRequest'] = _UPDATENOTICEREQUEST
DESCRIPTOR.message_types_by_name['UpdateNoticeResponse'] = _UPDATENOTICERESPONSE
DESCRIPTOR.message_types_by_name['UpdateNoticeMultiRequest'] = _UPDATENOTICEMULTIREQUEST
DESCRIPTOR.message_types_by_name['UpdateNoticeMultiResponse'] = _UPDATENOTICEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['UpdateBackgroundImageRequest'] = _UPDATEBACKGROUNDIMAGEREQUEST
DESCRIPTOR.message_types_by_name['UpdateBackgroundImageResponse'] = _UPDATEBACKGROUNDIMAGERESPONSE
DESCRIPTOR.message_types_by_name['UpdateBackgroundImageMultiRequest'] = _UPDATEBACKGROUNDIMAGEMULTIREQUEST
DESCRIPTOR.message_types_by_name['UpdateBackgroundImageMultiResponse'] = _UPDATEBACKGROUNDIMAGEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSlideImagesRequest'] = _UPDATESLIDEIMAGESREQUEST
DESCRIPTOR.message_types_by_name['UpdateSlideImagesResponse'] = _UPDATESLIDEIMAGESRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSlideImagesMultiRequest'] = _UPDATESLIDEIMAGESMULTIREQUEST
DESCRIPTOR.message_types_by_name['UpdateSlideImagesMultiResponse'] = _UPDATESLIDEIMAGESMULTIRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSoundRequest'] = _UPDATESOUNDREQUEST
DESCRIPTOR.message_types_by_name['UpdateSoundResponse'] = _UPDATESOUNDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSoundMultiRequest'] = _UPDATESOUNDMULTIREQUEST
DESCRIPTOR.message_types_by_name['UpdateSoundMultiResponse'] = _UPDATESOUNDMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['LanguageType'] = _LANGUAGETYPE
DESCRIPTOR.enum_types_by_name['BackgroundType'] = _BACKGROUNDTYPE
DESCRIPTOR.enum_types_by_name['BackgroundTheme'] = _BACKGROUNDTHEME
DESCRIPTOR.enum_types_by_name['DateFormat'] = _DATEFORMAT
DESCRIPTOR.enum_types_by_name['TimeFormat'] = _TIMEFORMAT
DESCRIPTOR.enum_types_by_name['SoundIndex'] = _SOUNDINDEX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DisplayConfig = _reflection.GeneratedProtocolMessageType('DisplayConfig', (_message.Message,), dict(
  DESCRIPTOR = _DISPLAYCONFIG,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.DisplayConfig)
  ))
_sym_db.RegisterMessage(DisplayConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

UpdateLanguagePackRequest = _reflection.GeneratedProtocolMessageType('UpdateLanguagePackRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATELANGUAGEPACKREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateLanguagePackRequest)
  ))
_sym_db.RegisterMessage(UpdateLanguagePackRequest)

UpdateLanguagePackResponse = _reflection.GeneratedProtocolMessageType('UpdateLanguagePackResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATELANGUAGEPACKRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateLanguagePackResponse)
  ))
_sym_db.RegisterMessage(UpdateLanguagePackResponse)

UpdateLanguagePackMultiRequest = _reflection.GeneratedProtocolMessageType('UpdateLanguagePackMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATELANGUAGEPACKMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateLanguagePackMultiRequest)
  ))
_sym_db.RegisterMessage(UpdateLanguagePackMultiRequest)

UpdateLanguagePackMultiResponse = _reflection.GeneratedProtocolMessageType('UpdateLanguagePackMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATELANGUAGEPACKMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateLanguagePackMultiResponse)
  ))
_sym_db.RegisterMessage(UpdateLanguagePackMultiResponse)

UpdateNoticeRequest = _reflection.GeneratedProtocolMessageType('UpdateNoticeRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATENOTICEREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateNoticeRequest)
  ))
_sym_db.RegisterMessage(UpdateNoticeRequest)

UpdateNoticeResponse = _reflection.GeneratedProtocolMessageType('UpdateNoticeResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATENOTICERESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateNoticeResponse)
  ))
_sym_db.RegisterMessage(UpdateNoticeResponse)

UpdateNoticeMultiRequest = _reflection.GeneratedProtocolMessageType('UpdateNoticeMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATENOTICEMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateNoticeMultiRequest)
  ))
_sym_db.RegisterMessage(UpdateNoticeMultiRequest)

UpdateNoticeMultiResponse = _reflection.GeneratedProtocolMessageType('UpdateNoticeMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATENOTICEMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateNoticeMultiResponse)
  ))
_sym_db.RegisterMessage(UpdateNoticeMultiResponse)

UpdateBackgroundImageRequest = _reflection.GeneratedProtocolMessageType('UpdateBackgroundImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBACKGROUNDIMAGEREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateBackgroundImageRequest)
  ))
_sym_db.RegisterMessage(UpdateBackgroundImageRequest)

UpdateBackgroundImageResponse = _reflection.GeneratedProtocolMessageType('UpdateBackgroundImageResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBACKGROUNDIMAGERESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateBackgroundImageResponse)
  ))
_sym_db.RegisterMessage(UpdateBackgroundImageResponse)

UpdateBackgroundImageMultiRequest = _reflection.GeneratedProtocolMessageType('UpdateBackgroundImageMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBACKGROUNDIMAGEMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateBackgroundImageMultiRequest)
  ))
_sym_db.RegisterMessage(UpdateBackgroundImageMultiRequest)

UpdateBackgroundImageMultiResponse = _reflection.GeneratedProtocolMessageType('UpdateBackgroundImageMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEBACKGROUNDIMAGEMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateBackgroundImageMultiResponse)
  ))
_sym_db.RegisterMessage(UpdateBackgroundImageMultiResponse)

UpdateSlideImagesRequest = _reflection.GeneratedProtocolMessageType('UpdateSlideImagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESLIDEIMAGESREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSlideImagesRequest)
  ))
_sym_db.RegisterMessage(UpdateSlideImagesRequest)

UpdateSlideImagesResponse = _reflection.GeneratedProtocolMessageType('UpdateSlideImagesResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESLIDEIMAGESRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSlideImagesResponse)
  ))
_sym_db.RegisterMessage(UpdateSlideImagesResponse)

UpdateSlideImagesMultiRequest = _reflection.GeneratedProtocolMessageType('UpdateSlideImagesMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESLIDEIMAGESMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSlideImagesMultiRequest)
  ))
_sym_db.RegisterMessage(UpdateSlideImagesMultiRequest)

UpdateSlideImagesMultiResponse = _reflection.GeneratedProtocolMessageType('UpdateSlideImagesMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESLIDEIMAGESMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSlideImagesMultiResponse)
  ))
_sym_db.RegisterMessage(UpdateSlideImagesMultiResponse)

UpdateSoundRequest = _reflection.GeneratedProtocolMessageType('UpdateSoundRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESOUNDREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSoundRequest)
  ))
_sym_db.RegisterMessage(UpdateSoundRequest)

UpdateSoundResponse = _reflection.GeneratedProtocolMessageType('UpdateSoundResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESOUNDRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSoundResponse)
  ))
_sym_db.RegisterMessage(UpdateSoundResponse)

UpdateSoundMultiRequest = _reflection.GeneratedProtocolMessageType('UpdateSoundMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESOUNDMULTIREQUEST,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSoundMultiRequest)
  ))
_sym_db.RegisterMessage(UpdateSoundMultiRequest)

UpdateSoundMultiResponse = _reflection.GeneratedProtocolMessageType('UpdateSoundMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATESOUNDMULTIRESPONSE,
  __module__ = 'display_pb2'
  # @@protoc_insertion_point(class_scope:display.UpdateSoundMultiResponse)
  ))
_sym_db.RegisterMessage(UpdateSoundMultiResponse)


DESCRIPTOR._options = None

_DISPLAY = _descriptor.ServiceDescriptor(
  name='Display',
  full_name='display.Display',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2625,
  serialized_end=3812,
  methods=[
  _descriptor.MethodDescriptor(
    name='UpdateLanguagePack',
    full_name='display.Display.UpdateLanguagePack',
    index=0,
    containing_service=None,
    input_type=_UPDATELANGUAGEPACKREQUEST,
    output_type=_UPDATELANGUAGEPACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLanguagePackMulti',
    full_name='display.Display.UpdateLanguagePackMulti',
    index=1,
    containing_service=None,
    input_type=_UPDATELANGUAGEPACKMULTIREQUEST,
    output_type=_UPDATELANGUAGEPACKMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotice',
    full_name='display.Display.UpdateNotice',
    index=2,
    containing_service=None,
    input_type=_UPDATENOTICEREQUEST,
    output_type=_UPDATENOTICERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNoticeMulti',
    full_name='display.Display.UpdateNoticeMulti',
    index=3,
    containing_service=None,
    input_type=_UPDATENOTICEMULTIREQUEST,
    output_type=_UPDATENOTICEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateBackgroundImage',
    full_name='display.Display.UpdateBackgroundImage',
    index=4,
    containing_service=None,
    input_type=_UPDATEBACKGROUNDIMAGEREQUEST,
    output_type=_UPDATEBACKGROUNDIMAGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateBackgroundImageMulti',
    full_name='display.Display.UpdateBackgroundImageMulti',
    index=5,
    containing_service=None,
    input_type=_UPDATEBACKGROUNDIMAGEMULTIREQUEST,
    output_type=_UPDATEBACKGROUNDIMAGEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSlideImages',
    full_name='display.Display.UpdateSlideImages',
    index=6,
    containing_service=None,
    input_type=_UPDATESLIDEIMAGESREQUEST,
    output_type=_UPDATESLIDEIMAGESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSlideImagesMulti',
    full_name='display.Display.UpdateSlideImagesMulti',
    index=7,
    containing_service=None,
    input_type=_UPDATESLIDEIMAGESMULTIREQUEST,
    output_type=_UPDATESLIDEIMAGESMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSound',
    full_name='display.Display.UpdateSound',
    index=8,
    containing_service=None,
    input_type=_UPDATESOUNDREQUEST,
    output_type=_UPDATESOUNDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSoundMulti',
    full_name='display.Display.UpdateSoundMulti',
    index=9,
    containing_service=None,
    input_type=_UPDATESOUNDMULTIREQUEST,
    output_type=_UPDATESOUNDMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='display.Display.GetConfig',
    index=10,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='display.Display.SetConfig',
    index=11,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='display.Display.SetConfigMulti',
    index=12,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISPLAY)

DESCRIPTOR.services_by_name['Display'] = _DISPLAY

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import tenant_pb2 as tenant__pb2


class TenantStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/tenant.Tenant/GetList',
        request_serializer=tenant__pb2.GetListRequest.SerializeToString,
        response_deserializer=tenant__pb2.GetListResponse.FromString,
        )
    self.Get = channel.unary_unary(
        '/tenant.Tenant/Get',
        request_serializer=tenant__pb2.GetRequest.SerializeToString,
        response_deserializer=tenant__pb2.GetResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/tenant.Tenant/Add',
        request_serializer=tenant__pb2.AddRequest.SerializeToString,
        response_deserializer=tenant__pb2.AddResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/tenant.Tenant/Delete',
        request_serializer=tenant__pb2.DeleteRequest.SerializeToString,
        response_deserializer=tenant__pb2.DeleteResponse.FromString,
        )
    self.AddGateway = channel.unary_unary(
        '/tenant.Tenant/AddGateway',
        request_serializer=tenant__pb2.AddGatewayRequest.SerializeToString,
        response_deserializer=tenant__pb2.AddGatewayResponse.FromString,
        )
    self.DeleteGateway = channel.unary_unary(
        '/tenant.Tenant/DeleteGateway',
        request_serializer=tenant__pb2.DeleteGatewayRequest.SerializeToString,
        response_deserializer=tenant__pb2.DeleteGatewayResponse.FromString,
        )
    self.CreateCertificate = channel.unary_unary(
        '/tenant.Tenant/CreateCertificate',
        request_serializer=tenant__pb2.CreateCertificateRequest.SerializeToString,
        response_deserializer=tenant__pb2.CreateCertificateResponse.FromString,
        )
    self.GetIssuanceHistory = channel.unary_unary(
        '/tenant.Tenant/GetIssuanceHistory',
        request_serializer=tenant__pb2.GetIssuanceHistoryRequest.SerializeToString,
        response_deserializer=tenant__pb2.GetIssuanceHistoryResponse.FromString,
        )
    self.GetCertificateBlacklist = channel.unary_unary(
        '/tenant.Tenant/GetCertificateBlacklist',
        request_serializer=tenant__pb2.GetCertificateBlacklistRequest.SerializeToString,
        response_deserializer=tenant__pb2.GetCertificateBlacklistResponse.FromString,
        )
    self.AddCertificateBlacklist = channel.unary_unary(
        '/tenant.Tenant/AddCertificateBlacklist',
        request_serializer=tenant__pb2.AddCertificateBlacklistRequest.SerializeToString,
        response_deserializer=tenant__pb2.AddCertificateBlacklistResponse.FromString,
        )
    self.DeleteCertificateBlacklist = channel.unary_unary(
        '/tenant.Tenant/DeleteCertificateBlacklist',
        request_serializer=tenant__pb2.DeleteCertificateBlacklistRequest.SerializeToString,
        response_deserializer=tenant__pb2.DeleteCertificateBlacklistResponse.FromString,
        )


class TenantServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddGateway(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteGateway(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CreateCertificate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetIssuanceHistory(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCertificateBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddCertificateBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteCertificateBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_TenantServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=tenant__pb2.GetListRequest.FromString,
          response_serializer=tenant__pb2.GetListResponse.SerializeToString,
      ),
      'Get': grpc.unary_unary_rpc_method_handler(
          servicer.Get,
          request_deserializer=tenant__pb2.GetRequest.FromString,
          response_serializer=tenant__pb2.GetResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=tenant__pb2.AddRequest.FromString,
          response_serializer=tenant__pb2.AddResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=tenant__pb2.DeleteRequest.FromString,
          response_serializer=tenant__pb2.DeleteResponse.SerializeToString,
      ),
      'AddGateway': grpc.unary_unary_rpc_method_handler(
          servicer.AddGateway,
          request_deserializer=tenant__pb2.AddGatewayRequest.FromString,
          response_serializer=tenant__pb2.AddGatewayResponse.SerializeToString,
      ),
      'DeleteGateway': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteGateway,
          request_deserializer=tenant__pb2.DeleteGatewayRequest.FromString,
          response_serializer=tenant__pb2.DeleteGatewayResponse.SerializeToString,
      ),
      'CreateCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.CreateCertificate,
          request_deserializer=tenant__pb2.CreateCertificateRequest.FromString,
          response_serializer=tenant__pb2.CreateCertificateResponse.SerializeToString,
      ),
      'GetIssuanceHistory': grpc.unary_unary_rpc_method_handler(
          servicer.GetIssuanceHistory,
          request_deserializer=tenant__pb2.GetIssuanceHistoryRequest.FromString,
          response_serializer=tenant__pb2.GetIssuanceHistoryResponse.SerializeToString,
      ),
      'GetCertificateBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.GetCertificateBlacklist,
          request_deserializer=tenant__pb2.GetCertificateBlacklistRequest.FromString,
          response_serializer=tenant__pb2.GetCertificateBlacklistResponse.SerializeToString,
      ),
      'AddCertificateBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.AddCertificateBlacklist,
          request_deserializer=tenant__pb2.AddCertificateBlacklistRequest.FromString,
          response_serializer=tenant__pb2.AddCertificateBlacklistResponse.SerializeToString,
      ),
      'DeleteCertificateBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteCertificateBlacklist,
          request_deserializer=tenant__pb2.DeleteCertificateBlacklistRequest.FromString,
          response_serializer=tenant__pb2.DeleteCertificateBlacklistResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'tenant.Tenant', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
